# The Sodium crypto library RPM .spec file
#
# Common usage:
#   rpmbuild -ba --clean "$(rpm --eval='%{_specdir}')/libsodium-1.0.6-centos6.spec"
#
# Possible additional switches:
#   --without todayepoch (don't set "Epoch" field to the current YYYYMMDD, leave it unspecified)
#   --without ownsourcedir (don't use separate "libsodium-x.x.x/" folder inside "rpmbuild/SOURCES/")
#   --with selftests (perform self-testing after successful build)

# Acceptable build conditions

%bcond_with todayepoch
%bcond_with ownsourcedir

# disable self-testing by default
%bcond_with selftests

# Version numbers

%define VerMajor       1
%define VerMinor       0
%define PatchLevel     6
%define Revision       1

%define ShortVersion   %{VerMajor}.%{VerMinor}
%define LongVersion    %{ShortVersion}.%{PatchLevel}

# Other globals and defines

%global CurDate        %(date +%Y%m%d)
%define DistroTag      %{?centos:.centos%{?centos_ver}%{!?centos_ver:%{centos}}}%{!?centos:%{?dist}}

# Header

Name: libsodium

Version: %{LongVersion}
Release: %{Revision}%{DistroTag}
%if %{with todayepoch}
Epoch: %{CurDate}
%endif

Summary: The Sodium crypto library
Group: System Environment/Libraries
License: ISC

URL: http://libsodium.org/

Vendor: Zarezky.spb.ru RPM repository, http://zarezky.spb.ru/yumrepo/
Packager: Elijah Zarezky <elijah@zarezky.spb.ru>

# Sources

%if %{with ownsourcedir}
%define _sourcedir %{_topdir}/SOURCES/%{name}-%{version}
%endif

Source0: https://download.libsodium.org/libsodium/releases/%{name}-%{version}.tar.gz

# Patches

# Directory for the (fake) install step

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Build requirements

BuildRequires: glibc-devel >= 2.12

# Run-time requirements

Requires: glibc >= 2.12

# Virtual package names

Provides: %{name} = %{version}-%{release}

# Description

%description
Sodium is a new, easy-to-use software library for encryption, decryption, 
signatures, password hashing and more. It is a portable, cross-compilable, 
installable, packageable fork of NaCl, with a compatible API, and an extended 
API to improve usability even further. Its goal is to provide all of the core 
operations needed to build higher-level cryptographic tools. The design 
choices emphasize security, and "magic constants" have clear rationales.

The same cannot be said of NIST curves, where the specific origins of certain 
constants are not described by the standards. And despite the emphasis on 
higher security, primitives are faster across-the-board than most 
implementations of the NIST standards.

# Subpackages

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}

%description    devel
This package contains libraries and header files for developing applications
that use %{name} libraries.

# Build scripts

%prep
%setup -q -n %{name}-%{version}

%build
export CFLAGS="%{optflags} -w"
export CXXFLAGS="%{optflags} -w"

%configure --enable-shared --disable-static
%{__make} %{?_smp_mflags}

%check
%if %{with selftests}
%{__make} check
%endif

%install
%{__rm} -rf %{buildroot}

%{__make} install DESTDIR=%{buildroot}
find %{buildroot} -name '*.la' -delete -print

%clean
%{__rm} -rf %{buildroot}

# Install/uninstall scripts

%pretrans

%pre

%post -p /sbin/ldconfig

%preun

%postun -p /sbin/ldconfig

%posttrans

# Files to install

%files
%defattr(-, root, root, -)
%doc AUTHORS ChangeLog LICENSE README README.markdown THANKS
%{_libdir}/libsodium.so.*

%files devel
%defattr(-, root, root, -)
%doc test/default/*.{c,exp,h}
%doc test/quirks/quirks.h
%{_includedir}/sodium.h
%dir %{_includedir}/sodium
%{_includedir}/sodium/*
%{_libdir}/libsodium.so
%{_libdir}/pkgconfig/libsodium.pc

# Changes in the package

%changelog
* Fri Dec 04 2015 Elijah Zarezky <elijah@zarezky.spb.ru> - 1.0.6-1
- Initial package.
- Built using "--with selftests".
